@@ -32,26 +32,16 @@ if gajim.HAVE_GPG:
     gnupg.logger = logging.getLogger('gajim.c.gnupg')
 
     class GnuPG(gnupg.GPG):
-        def __init__(self, use_agent=False):
-            gnupg.GPG.__init__(self, gpgbinary=gajim.GPG_BINARY)
+        def __init__(self):
+            use_agent = gajim.config.get('use_gpg_agent')
+            gnupg.GPG.__init__(self, gpgbinary=gajim.GPG_BINARY, use_agent=use_agent)
             encoding = gajim.config.get('pgp_encoding')
             if encoding:
                 self.encoding = encoding
             self.decode_errors = 'replace'
             self.passphrase = None
-            self.use_agent = use_agent
             self.always_trust = [] # list of keyID to always trust
 
-        def _setup_my_options(self):
-            self.options.armor = 1
-            self.options.meta_interactive = 0
-            self.options.extra_args.append('--no-secmem-warning')
-            # disable photo viewer when verifying keys
-            self.options.extra_args.append('--verify-options')
-            self.options.extra_args.append('no-show-photo')
-            if self.use_agent:
-                self.options.extra_args.append('--use-agent')
-
         def encrypt(self, str_, recipients, always_trust=False):
             trust = always_trust
             if not trust:
@@ -69,7 +59,7 @@ if gajim.HAVE_GPG:
                             return '', 'NOT_TRUSTED ' + key['keyid'][-8:]
                         else:
                             trust = True
-            result = super(GnuPG, self).encrypt(str_, recipients,
+            result = super(GnuPG, self).encrypt(str_.encode('utf8'), recipients,
                 always_trust=trust, passphrase=self.passphrase)
 
             if result.ok:
@@ -81,13 +71,13 @@ if gajim.HAVE_GPG:
 
         def decrypt(self, str_, keyID):
             data = self._addHeaderFooter(str_, 'MESSAGE')
-            result = super(GnuPG, self).decrypt(data,
+            result = super(GnuPG, self).decrypt(data.encode('utf8'),
                 passphrase=self.passphrase)
 
             return str(result)
 
         def sign(self, str_, keyID):
-            result = super(GnuPG, self).sign(str_, keyid=keyID, detach=True,
+            result = super(GnuPG, self).sign(str_.encode('utf8'), keyid=keyID, detach=True,
                 passphrase=self.passphrase)
 
             if result.fingerprint:
@@ -110,7 +100,7 @@ if gajim.HAVE_GPG:
                      str_,
                      self._addHeaderFooter(sign, 'SIGNATURE')]
                     )
-                result = super(GnuPG, self).verify(data)
+                result = super(GnuPG, self).verify(data.encode('utf8'))
                 if result.valid:
                     return result.key_id
 
