@@ -112,7 +112,7 @@ def parse_jid(jidstring):
     """
     # This function comes from http://svn.twistedmatrix.com/cvs/trunk/twisted/words/protocols/jabber/jid.py
 
-    return prep(*decompose_jid(jidstring))
+    return prep(*decompose_jid(str(jidstring)))
 
 def idn_to_ascii(host):
     """
@@ -405,7 +405,7 @@ def is_in_path(command, return_abs_path=False):
             pass
     return False
 
-def exec_command(command, use_shell=False):
+def exec_command(command, use_shell=False, posix=True):
     """
     execute a command. if use_shell is True, we run the command as is it was
     typed in a console. So it may be dangerous if you are not sure about what
@@ -414,7 +414,7 @@ def exec_command(command, use_shell=False):
     if use_shell:
         subprocess.Popen('%s &' % command, shell=True).wait()
     else:
-        args = shlex.split(command.encode('utf-8'))
+        args = shlex.split(command.encode('utf-8'), posix=posix)
         p = subprocess.Popen(args)
         gajim.thread_interface(p.wait)
 
